'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const defaultUiConfig = require('./default-ui-config-8a058612.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const index$1 = require('./index-dbc5b08f.js');
const index$2 = require('./index-7a96dd15.js');
const store = require('./store-d570e98c.js');
require('./default-language-4c779255.js');

const dyteGridCss = ":host{display:flex;height:100%;width:100%;overflow:hidden;font-family:var(--dyte-font-family, sans-serif);flex-wrap:wrap;align-content:center;align-items:center;justify-content:center;color:rgb(var(--dyte-colors-text-1000, 255 255 255));transition:0.4s}dyte-participant-tile{aspect-ratio:initial;box-sizing:border-box}";

const DyteGrid = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.stateUpdate = index.createEvent(this, "dyteStateUpdate", 7);
    this.participants = [];
    this.pinnedParticipants = [];
    this.screenShareParticipants = [];
    this.plugins = [];
    this.responsiveGap = 4;
    this.dimensions = [0, 0];
    /** The aspect ratio of each participant */
    this.aspectRatio = '16:9';
    /** Gap between participants */
    this.gap = 8;
    /** Config object */
    this.config = defaultUiConfig.defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
    this.onViewModeChanged = ({ viewMode }) => {
      if (this.meeting == null)
        return;
      if (viewMode === 'PAGINATED') {
        // if paginated, remove self
        this.participants = this.participants.filter((p) => p.id !== this.meeting.self.id);
      }
      else if (!this.participants.some((p) => p.id === this.meeting.self.id)) {
        // if active, add self
        this.participants = [...this.participants, this.meeting.self];
      }
    };
    this.onParticipantJoined = (participant) => {
      if (this.meeting == null)
        return;
      if (!this.participants.some((p) => p.id === participant.id)) {
        const lastItem = this.participants[this.participants.length - 1];
        const { self } = this.meeting;
        if (lastItem != null && lastItem.id === self.id) {
          // get all participants except the last self one
          const remainingParticipants = this.participants.slice(0, -1);
          this.participants = [...remainingParticipants, participant, self];
        }
        else {
          this.participants = [...this.participants, participant];
        }
      }
    };
    this.onParticipantLeft = (participant) => {
      this.participants = this.participants.filter((p) => p.id !== participant.id);
      if (participant.screenShareEnabled) {
        this.removeScreenShare(participant);
      }
    };
    this.onScreenShareUpdate = (participant) => {
      if (participant.screenShareEnabled) {
        this.addScreenShare(participant);
      }
      else {
        this.removeScreenShare(participant);
      }
    };
    this.onSelfScreenShareUpdate = ({ screenShareEnabled, }) => {
      if (screenShareEnabled) {
        this.addScreenShare(this.meeting.self);
      }
      else {
        this.removeScreenShare(this.meeting.self);
      }
    };
    this.onPluginStateUpdate = (plugin, { active }) => {
      if (active) {
        if (!this.plugins.some((p) => p.id === plugin.id)) {
          this.plugins = [...this.plugins, plugin];
        }
      }
      else {
        this.plugins = this.plugins.filter((p) => p.id !== plugin.id);
      }
    };
    this.onParticipantPinned = (participant) => {
      this.pinnedParticipants = [...this.pinnedParticipants, participant];
    };
    this.onParticipantUnpinned = (participant) => {
      this.pinnedParticipants = this.pinnedParticipants.filter((p) => p.id !== participant.id);
    };
  }
  connectedCallback() {
    this.sizeChanged(this.size);
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    const { self, participants, plugins } = this.meeting;
    participants.active.removeListener('participantJoined', this.onParticipantJoined);
    participants.active.removeListener('participantLeft', this.onParticipantLeft);
    participants.joined.removeListener('screenShareUpdate', this.onScreenShareUpdate);
    self.removeListener('screenShareUpdate', this.onSelfScreenShareUpdate);
    plugins.removeListener('stateUpdate', this.onPluginStateUpdate);
    participants.pinned.removeListener('participantJoined', this.onParticipantPinned);
    participants.pinned.removeListener('participantLeft', this.onParticipantUnpinned);
    self.removeListener('pinned', this.onParticipantPinned);
    self.removeListener('unpinned', this.onParticipantUnpinned);
    participants.removeListener('viewModeChanged', this.onViewModeChanged);
  }
  sizeChanged(size) {
    this.responsiveGap = size === 'sm' ? this.gap / 2 : this.gap;
  }
  screenShareParticipantsChanged(participants) {
    const activeScreenShare = participants.length > 0;
    this.stateUpdate.emit({ activeScreenShare });
    store.state.activeScreenShare = activeScreenShare;
  }
  pluginsChanged(plugins) {
    const activePlugin = plugins.length > 0;
    this.stateUpdate.emit({ activePlugin });
    store.state.activePlugin = activePlugin;
  }
  pinnedParticipantsChanged(participants) {
    const activeSpotlight = participants.length > 0;
    this.stateUpdate.emit({ activeSpotlight });
    store.state.activeSpotlight = activeSpotlight;
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const { self, participants, plugins } = meeting;
      // Initialize values
      this.participants = [
        ...participants.active.toArray(),
        ...(participants.viewMode === 'ACTIVE_GRID' ? [self] : []),
      ];
      this.pinnedParticipants = [
        ...participants.pinned.toArray(),
        ...(self.isPinned ? [self] : []),
      ];
      this.screenShareParticipants = participants.joined
        .toArray()
        .filter((participant) => participant.screenShareEnabled);
      this.plugins = plugins.active.toArray();
      // Add all listeners
      participants.active.addListener('participantJoined', this.onParticipantJoined);
      participants.active.addListener('participantLeft', this.onParticipantLeft);
      participants.joined.addListener('screenShareUpdate', this.onScreenShareUpdate);
      self.addListener('screenShareUpdate', this.onSelfScreenShareUpdate);
      plugins.all.addListener('stateUpdate', this.onPluginStateUpdate);
      participants.pinned.addListener('participantJoined', this.onParticipantPinned);
      participants.pinned.addListener('participantLeft', this.onParticipantUnpinned);
      self.addListener('pinned', this.onParticipantPinned);
      self.addListener('unpinned', this.onParticipantUnpinned);
      participants.addListener('viewModeChanged', this.onViewModeChanged);
    }
  }
  addScreenShare(participant) {
    if (!this.screenShareParticipants.some((p) => p.id === participant.id)) {
      this.screenShareParticipants = [...this.screenShareParticipants, participant];
    }
  }
  removeScreenShare(participant) {
    this.screenShareParticipants = this.screenShareParticipants.filter((p) => p.id !== participant.id);
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      size: this.size,
      states: this.states || store.state,
      config: this.config,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (index.h(index.Host, null, index.h(index$2.Render, { element: "dyte-grid", defaults: defaults, childProps: {
        participants: this.participants,
        screenShareParticipants: this.screenShareParticipants,
        plugins: this.plugins,
        pinnedParticipants: this.pinnedParticipants,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
      }, onlyChildren: true })));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "size": ["sizeChanged"],
    "screenShareParticipants": ["screenShareParticipantsChanged"],
    "plugins": ["pluginsChanged"],
    "pinnedParticipants": ["pinnedParticipantsChanged"],
    "meeting": ["meetingChanged"]
  }; }
};
DyteGrid.style = dyteGridCss;

exports.dyte_grid = DyteGrid;
