'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const index$1 = require('./index-dbc5b08f.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const defaultUiConfig = require('./default-ui-config-8a058612.js');
const index$2 = require('./index-7a96dd15.js');
const config = require('./config-6e62381d.js');
const userPrefs = require('./user-prefs-2b7b905f.js');
const store = require('./store-d570e98c.js');
const versionTwoApis = require('./versionTwoApis-9c9006ae.js');
require('./default-language-4c779255.js');
require('./graceful-storage-945bc8be.js');

const getIconPack = async (url) => {
  // check for both null/undefined
  if (url == null) {
    return defaultIconPack.defaultIconPack;
  }
  try {
    const res = await fetch(url);
    if (!res.ok) {
      return defaultIconPack.defaultIconPack;
    }
    // merge defaultIconPack with the received iconPack so as to
    // fill the missing icons with default ones
    return Object.assign({}, defaultIconPack.defaultIconPack, await res.json());
  }
  catch (_) {
    return defaultIconPack.defaultIconPack;
  }
};

const sm = 640;
const md = 768;
const lg = 1080;
const xl = 2160;
const breakpoints = {
	sm: sm,
	md: md,
	lg: lg,
	xl: xl
};

/**
 * Get the screen breakpoint from a given width
 * @param width The width of the container
 * @returns The screen breakpoint value
 */
const getSize = (width) => {
  if (width >= breakpoints.lg)
    return 'lg';
  else if (width >= breakpoints.md)
    return 'md';
  else
    return 'sm';
};

const dyteMeetingCss = ":host{box-sizing:border-box;display:flex;flex-direction:column;font-family:var(--dyte-font-family, sans-serif);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));overflow:hidden;position:fixed;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);height:100%;width:100%}:host([mode='fill']){position:relative}";

const DyteMeeting = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.roomJoinedListener = () => {
      this.setStates({ meeting: 'joined' });
      store.state.meeting = 'joined';
    };
    this.roomLeftListener = ({ state }) => {
      const states = this.states || store.state;
      if ((states === null || states === void 0 ? void 0 : states.roomLeftState) === 'disconnected') {
        this.setStates({ meeting: 'ended' });
        store.state.meeting = 'ended';
        return;
      }
      this.setStates({ meeting: 'ended', roomLeftState: state });
      store.state.meeting = 'ended';
      store.state.roomLeftState = state;
    };
    this.mediaPermissionErrorListener = ({ kind }) => {
      if (['audio', 'video'].includes(kind)) {
        this.setStates({ activePermissionsMessage: true });
        store.state.activePermissionsMessage = true;
      }
    };
    /** Whether to load config from preset */
    this.loadConfigFromPreset = true;
    /** Whether to apply the design system on the document root from config */
    this.applyDesignSystem = true;
    /** Fill type */
    this.mode = 'fixed';
    /** Language */
    this.language = 'en';
    /** UI Config */
    this.config = defaultUiConfig.defaultConfig;
    this.states = {
      meeting: 'idle',
      prefs: {
        mirrorVideo: true,
        muteNotificationSounds: false,
        autoScroll: true,
      },
    };
    this.iconPack = defaultIconPack.defaultIconPack;
    this.t = index$1.useLanguage();
  }
  connectedCallback() {
    var _a;
    this.resizeObserver = new ResizeObserver(() => this.handleResize());
    this.resizeObserver.observe(this.host);
    if (this.applyDesignSystem &&
      ((_a = this.config) === null || _a === void 0 ? void 0 : _a.designTokens) != null &&
      typeof document !== 'undefined') {
      config.provideDyteDesignSystem(document.documentElement, this.config.designTokens);
    }
    this.meetingChanged(this.meeting);
    this.iconPackUrlChanged(this.iconPackUrl);
    this.languageChanged(this.language);
    this.initializePreferences();
  }
  disconnectedCallback() {
    var _a, _b;
    this.resizeObserver.disconnect();
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('roomJoined', this.roomJoinedListener);
    (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.removeListener('roomLeft', this.roomLeftListener);
  }
  meetingChanged(meeting) {
    var _a;
    if (meeting != null) {
      if (this.loadConfigFromPreset && meeting.self.suggestedTheme != null) {
        const theme = meeting.self.suggestedTheme;
        const { config: config$1, data } = versionTwoApis.isV2Theme(theme)
          ? { config: defaultUiConfig.defaultConfig, data: { showSetupScreen: true } }
          : config.generateConfig(theme);
        if (this.config === defaultUiConfig.defaultConfig) {
          // only override the config if the object is same as defaultConfig
          // which means it's a different object passed via prop
          this.config = config$1;
        }
        if (this.showSetupScreen == null) {
          // only override this value if the prop isn't passed
          this.showSetupScreen = data.showSetupScreen;
        }
      }
      meeting.self.addListener('roomJoined', this.roomJoinedListener);
      meeting.self.addListener('roomLeft', this.roomLeftListener);
      meeting.self.addListener('mediaPermissionError', this.mediaPermissionErrorListener);
      if (this.applyDesignSystem &&
        ((_a = this.config) === null || _a === void 0 ? void 0 : _a.designTokens) != null &&
        typeof document !== 'undefined') {
        config.provideDyteDesignSystem(document.documentElement, this.config.designTokens);
      }
      if (this.showSetupScreen) {
        this.states = Object.assign(Object.assign({}, this.states), { meeting: 'setup' });
        store.state.meeting = 'setup';
      }
      else {
        // join directly to the meeting
        meeting.joinRoom();
      }
    }
  }
  async iconPackUrlChanged(url) {
    this.iconPack = await getIconPack(url);
  }
  async languageChanged(lang) {
    this.t = index$1.useLanguage(await index$1.getLangData(lang));
  }
  listenState(e) {
    e.stopPropagation();
    this.setStates(e.detail);
  }
  initializePreferences() {
    const prefs = userPrefs.getUserPreferences();
    this.setStates({ prefs });
    store.state.prefs = prefs;
  }
  handleResize() {
    this.size = getSize(this.host.clientWidth);
  }
  setStates(states) {
    this.states = Object.assign(Object.assign({}, this.states), states);
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      size: this.size,
      states: this.states || store.state,
      config: this.config,
      iconPack: this.iconPack,
      t: this.t,
    };
    return index.h(index$2.Render, { element: "dyte-meeting", defaults: defaults, asHost: true });
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "iconPackUrl": ["iconPackUrlChanged"],
    "language": ["languageChanged"]
  }; }
};
DyteMeeting.style = dyteMeetingCss;

exports.dyte_meeting = DyteMeeting;
