import { Component, Host, h, Prop, Watch, State } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
const addZero = (n) => Math.trunc(n).toString().padStart(2, '0');
export class DyteClock {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.startedTime = '';
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    this.timeout && clearTimeout(this.timeout);
    typeof this.request === 'number' && cancelAnimationFrame(this.request);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.startedTime = meeting.meta.meetingStartedTimestamp.toISOString();
    }
  }
  startedTimeChanged(startedTime) {
    if (startedTime !== '') {
      const animate = () => {
        this.timeDiff = (Date.now() - new Date(this.startedTime).getTime()) / 1000;
        this.timeout = setTimeout(() => {
          if (this.request != null) {
            this.request = requestAnimationFrame(animate);
          }
        }, 500);
      };
      this.request = requestAnimationFrame(animate);
    }
  }
  getFormattedTime() {
    if (this.timeDiff == null) {
      return null;
    }
    const diff = this.timeDiff;
    let time = '';
    if (diff >= 3600) {
      time = `${addZero(diff / 3600)}:`;
    }
    time += `${addZero((diff % 3600) / 60)}:${addZero(diff % 60)}`;
    return time;
  }
  render() {
    return (h(Host, { tabIndex: 0, role: "timer", "aria-live": "off" },
      h("dyte-icon", { icon: this.iconPack.clock, "aria-hidden": true, tabIndex: -1, part: "icon" }),
      h("span", { part: "text" }, this.getFormattedTime())));
  }
  static get is() { return "dyte-clock"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-clock.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-clock.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "startedTime": {},
    "timeDiff": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }, {
      "propName": "startedTime",
      "methodName": "startedTimeChanged"
    }]; }
}
