import { Component, Host, h, Prop } from '@stencil/core';
import { computePosition, flip, offset, shift } from '@floating-ui/dom';
/**
 * A menu component.
 *
 * @slot - Default slot where you put the contents that you want inside menu
 * @slot trigger - Slot where you put your trigger element, clicking on which will open the menu
 */
export class DyteMenu {
  constructor() {
    this.clickedThis = false;
    /** Placement of menu */
    this.placement = 'bottom-end';
    this.handleOutsideClick = () => {
      // handles clicking on other menu triggers
      if (!this.clickedThis) {
        // if other trigger is clicked, hide this menu-list
        this.menuListEl.style.display = 'none';
      }
      // reset the value
      this.clickedThis = false;
    };
  }
  componentDidLoad() {
    document.addEventListener('click', this.handleOutsideClick);
    this.update();
  }
  disconnectedCallback() {
    document.removeEventListener('click', this.handleOutsideClick);
  }
  update() {
    computePosition(this.triggerEl, this.menuListEl, {
      placement: this.placement,
      middleware: [offset(10), flip(), shift({ padding: 5 })],
    }).then(({ x, y }) => {
      Object.assign(this.menuListEl.style, {
        left: `${x}px`,
        top: `${y}px`,
      });
    });
  }
  render() {
    return (h(Host, null,
      h("span", { id: "trigger", ref: (el) => (this.triggerEl = el), onClick: () => {
          this.clickedThis = true;
          if (this.menuListEl.style.display !== 'block') {
            this.menuListEl.style.display = 'block';
            this.update();
          }
          else {
            this.menuListEl.style.display = 'none';
          }
        } },
        h("slot", { name: "trigger" })),
      h("span", { part: "menu-list", id: "menu-list", ref: (el) => (this.menuListEl = el) },
        h("slot", null))));
  }
  static get is() { return "dyte-menu"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-menu.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-menu.css"]
  }; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "placement": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Placement",
        "resolved": "\"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
        "references": {
          "Placement": {
            "location": "import",
            "path": "@floating-ui/dom"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Placement of menu"
      },
      "attribute": "placement",
      "reflect": false,
      "defaultValue": "'bottom-end'"
    }
  }; }
}
